@@ -36,8 +36,8 @@ class RunscopeAdapter(HTTPAdapter):
         if port:
             request.headers["Runscope-Request-Port"] = port
 
-        if auth_token:
-            request.headers["Runscope-Bucket-Auth"] = auth_token
+        if self.auth_token:
+            request.headers["Runscope-Bucket-Auth"] = self.auth_token
 
         return super(RunscopeAdapter, self).send(request, **kwargs)
 
@@ -74,4 +74,5 @@ class RunscopeAdapter(HTTPAdapter):
         if parts.port:
             port = parts.port
 
-        return urlparse.urlunsplit((parts.scheme, new_host, parts.path, parts.query, parts.fragment)), port
\ No newline at end of file
+        return urlparse.urlunsplit((parts.scheme, new_host, parts.path, parts.query, parts.fragment)), port
+
